@@ -34,7 +34,7 @@
 #include "calls-sip-util.h"
 #include "calls-sip-media-manager.h"
 #include "calls-network-watch.h"
-#include "config.h"
+#include "calls-config.h"
 #include "enum-types.h"
 
 #include <glib/gi18n.h>
@@ -61,6 +61,7 @@ enum {
   PROP_0,
   PROP_NAME,
   PROP_ID,
+  PROP_EMERGENCY_NUMBERS,
   PROP_ACC_HOST,
   PROP_ACC_USER,
   PROP_ACC_PASSWORD,
@@ -361,10 +362,14 @@ dial (CallsOrigin *origin,
                    TAG_END ());
 
   /* Make sure @host is in the dial target */
-  if (g_strstr_len (address, -1, "@"))
+  if (g_strstr_len (address, -1, "@")) {
     dial_target = g_strdup (address);
-  else
-    dial_target = g_strconcat (address, "@", self->host, NULL);
+  } else {
+    if (self->port > 0)
+      dial_target = g_strdup_printf ("%s@%s:%d", address, self->host, self->port);
+    else
+      dial_target = g_strconcat (address, "@", self->host, NULL);
+  }
 
   g_debug ("Calling `%s' from origin '%s'", address, name);
 
@@ -1397,6 +1402,10 @@ calls_sip_origin_get_property (GObject    *object,
     g_value_set_string (value, self->id);
     break;
 
+  case PROP_EMERGENCY_NUMBERS:
+    g_value_set_boxed (value, NULL);
+    break;
+
   case PROP_ACC_HOST:
     g_value_set_string (value, self->host);
     break;
@@ -1644,6 +1653,7 @@ calls_sip_origin_class_init (CallsSipOriginClass *klass)
   IMPLEMENTS (PROP_COUNTRY_CODE, "country-code");
   IMPLEMENTS (PROP_ACC_STATE, "account-state");
   IMPLEMENTS (PROP_ACC_ADDRESS, "address");
+  IMPLEMENTS (PROP_EMERGENCY_NUMBERS, "emergency-numbers");
 
 #undef IMPLEMENTS
 }
